// header.component.ts
import { Component } from '@angular/core';
import { CommonModule } from '@angular/common';

@Component({
  selector: 'app-header',
  standalone: true,
  imports: [CommonModule],
  template: `
    <header>
      <div class="logo">
        <div class="logo-icon">
          <i class="fas fa-crown"></i>
        </div>
        <div class="logo-text">
          <h1>九州管理</h1>
          <p>智能AI权限管理系统</p>
        </div>
      </div>
      <div class="user-actions">
        <button class="btn btn-outline">
          <i class="fas fa-sync-alt"></i> 刷新数据
        </button>
        <button class="btn btn-primary" (click)="addSales()">
          <i class="fas fa-plus"></i> 添加销售
        </button>
      </div>
    </header>
  `,
  styles: [`
    header {
      display: flex;
      justify-content: space-between;
      align-items: center;
      padding: 20px 0;
      margin-bottom: 30px;
      border-bottom: 1px solid rgba(255, 255, 255, 0.2);
    }
    
    .logo {
      display: flex;
      align-items: center;
      gap: 15px;
    }
    
    .logo-icon {
      width: 50px;
      height: 50px;
      background: linear-gradient(135deg, #1a56db, #3b82f6);
      border-radius: 12px;
      display: flex;
      align-items: center;
      justify-content: center;
      font-size: 24px;
      box-shadow: 0 8px 32px rgba(31, 38, 135, 0.15);
    }
    
    .logo-text h1 {
      font-size: 24px;
      font-weight: 700;
      background: linear-gradient(to right, #fbcfe8, #c7d2fe);
      -webkit-background-clip: text;
      -webkit-text-fill-color: transparent;
    }
    
    .logo-text p {
      font-size: 14px;
      color: #cbd5e1;
      letter-spacing: 1px;
    }
    
    .user-actions {
      display: flex;
      gap: 15px;
    }
  `]
})
export class HeaderComponent {
  addSales() {
    // 实际逻辑在父组件处理
  }
}