// permission-modal.component.ts
import { Component, Input, Output, EventEmitter } from '@angular/core';
import { CommonModule } from '@angular/common';

@Component({
  selector: 'app-permission-modal',
  standalone: true,
  imports: [CommonModule],
  template: `
    <div class="permission-modal active" (click)="onBackdropClick($event)">
      <div class="modal-content">
        <div class="modal-header">
          <h2>{{ currentSales?.name }} - 权限管理</h2>
          <button class="close-btn" (click)="onClose()">&times;</button>
        </div>
        <div class="modal-body">
          <div class="ai-recommendation">
            <p><i class="fas fa-lightbulb"></i> {{ getAiRecommendation() }}</p>
            <button class="btn btn-primary" (click)="onApplyAi()">
              <i class="fas fa-check"></i> 应用AI建议
            </button>
          </div>
          
          <div class="permission-options">
            <!-- 权限选项保持不变 -->
          </div>
        </div>
        <div class="modal-footer">
          <button class="btn btn-outline" (click)="onClose()">取消</button>
          <button class="btn btn-primary" (click)="onSave()">保存设置</button>
        </div>
      </div>
    </div>
  `,
  styles: [`
    .permission-modal {
      position: fixed;
      top: 0;
      left: 0;
      right: 0;
      bottom: 0;
      background: rgba(15, 23, 42, 0.9);
      display: flex;
      align-items: center;
      justify-content: center;
      z-index: 1000;
    }
    
    .modal-content {
      background: rgba(255, 255, 255, 0.85);
      width: 90%;
      max-width: 600px;
      border-radius: 20px;
      box-shadow: 0 8px 32px rgba(31, 38, 135, 0.15);
      overflow: hidden;
    }
    
    .modal-header {
      padding: 20px;
      background: linear-gradient(135deg, #1a56db, #3b82f6);
      color: white;
      display: flex;
      justify-content: space-between;
      align-items: center;
    }
    
    .modal-header h2 {
      font-size: 22px;
    }
    
    .close-btn {
      background: transparent;
      border: none;
      color: white;
      font-size: 24px;
      cursor: pointer;
    }
    
    .modal-body {
      padding: 25px;
      color: #0f172a;
    }
    
    .ai-recommendation {
      background: rgba(26, 86, 219, 0.1);
      border-left: 4px solid #1a56db;
      padding: 15px;
      margin-bottom: 20px;
      border-radius: 0 8px 8px 0;
    }
    
    .ai-recommendation p {
      margin-bottom: 10px;
    }
    
    .permission-options {
      display: flex;
      flex-direction: column;
      gap: 15px;
    }
    
    .permission-option {
      display: flex;
      justify-content: space-between;
      align-items: center;
      padding: 12px 15px;
      background: rgba(241, 245, 249, 0.5);
      border-radius: 10px;
    }
    
    .permission-info {
      flex: 1;
    }
    
    .permission-info h3 {
      font-size: 16px;
      margin-bottom: 5px;
    }
    
    .permission-info p {
      font-size: 13px;
      color: #64748b;
    }
    
    .switch {
      position: relative;
      display: inline-block;
      width: 50px;
      height: 24px;
    }
    
    .switch input {
      opacity: 0;
      width: 0;
      height: 0;
    }
    
    .slider {
      position: absolute;
      cursor: pointer;
      top: 0;
      left: 0;
      right: 0;
      bottom: 0;
      background-color: #ccc;
      transition: .4s;
      border-radius: 24px;
    }
    
    .slider:before {
      position: absolute;
      content: "";
      height: 16px;
      width: 16px;
      left: 4px;
      bottom: 4px;
      background-color: white;
      transition: .4s;
      border-radius: 50%;
    }
    
    input:checked + .slider {
      background-color: #10b981;
    }
    
    input:checked + .slider:before {
      transform: translateX(26px);
    }
    
    .modal-footer {
      padding: 20px;
      display: flex;
      justify-content: flex-end;
      gap: 15px;
      border-top: 1px solid rgba(0, 0, 0, 0.1);
    }
  `]
})
export class PermissionModalComponent {
  @Input() currentSales: any;
  @Output() close = new EventEmitter<void>();
  @Output() applyAi = new EventEmitter<void>();
  @Output() save = new EventEmitter<void>();

  onBackdropClick(event: MouseEvent) {
    if ((event.target as HTMLElement).classList.contains('permission-modal')) {
      this.onClose();
    }
  }

  onClose() {
    this.close.emit();
  }

  onApplyAi() {
    this.applyAi.emit();
  }

  onSave() {
    this.save.emit();
  }

  getAiRecommendation(): string {
    if (!this.currentSales) return '';
    
    switch(this.currentSales.levelName) {
      case '实习销售':
        return 'AI建议：根据该销售表现，建议升级为<span class="ai-highlight">白银销售</span>权限级别';
      case '白银销售':
        return 'AI建议：根据该销售表现，建议升级为<span class="ai-highlight">黄金销售</span>权限级别';
      case '黄金销售':
        return 'AI建议：根据该销售表现，建议升级为<span class="ai-highlight">铂金销售</span>权限级别';
      case '铂金销售':
        return 'AI建议：根据该销售表现，建议升级为<span class="ai-highlight">钻石销售</span>权限级别';
      default:
        return 'AI建议：该销售已达到最高权限级别，表现优秀';
    }
  }
}