// sidebar.component.ts
import { Component, EventEmitter, Output } from '@angular/core';
import { CommonModule } from '@angular/common';

@Component({
  selector: 'app-sidebar',
  standalone: true,
  imports: [CommonModule],
  template: `
    <div class="sidebar">
      <!-- 其他内容保持不变 -->
      <button class="btn btn-primary" style="margin-top: 15px;" (click)="onAiRecommend()">
        <i class="fas fa-robot"></i> AI智能推荐
      </button>
    </div>
  `,
  styles: [`
    .sidebar {
      flex: 0 0 280px;
      background: rgba(255, 255, 255, 0.1);
      backdrop-filter: blur(10px);
      border-radius: 20px;
      border: 1px solid rgba(255, 255, 255, 0.2);
      padding: 25px;
      box-shadow: 0 8px 32px rgba(31, 38, 135, 0.15);
      height: fit-content;
    }
    
    .section-title {
      font-size: 18px;
      font-weight: 600;
      margin-bottom: 20px;
      display: flex;
      align-items: center;
      gap: 10px;
      color: #e2e8f0;
    }
    
    .section-title i {
      color: #f59e0b;
    }
    
    .filters {
      display: flex;
      flex-direction: column;
      gap: 15px;
    }
    
    .filter-group {
      display: flex;
      flex-direction: column;
      gap: 8px;
    }
    
    .filter-group label {
      font-size: 14px;
      color: #94a3b8;
      font-weight: 500;
    }
    
    .tag-filters {
      display: flex;
      flex-wrap: wrap;
      gap: 10px;
      margin-top: 5px;
    }
    
    .tag {
      padding: 5px 12px;
      border-radius: 20px;
      font-size: 12px;
      font-weight: 500;
      cursor: pointer;
      transition: all 0.2s ease;
    }
    
    .tag:hover {
      transform: translateY(-2px);
    }
    
    .tag.active {
      box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
    }
    
    .tag-rookie {
      background: linear-gradient(135deg, #60a5fa, #3b82f6);
      color: white;
    }
    
    .tag-silver {
      background: linear-gradient(135deg, #cbd5e1, #94a3b8);
      color: #0f172a;
    }
    
    .tag-gold {
      background: linear-gradient(135deg, #fcd34d, #f59e0b);
      color: #0f172a;
    }
    
    .tag-platinum {
      background: linear-gradient(135deg, #a5b4fc, #818cf8);
      color: white;
    }
    
    .tag-diamond {
      background: linear-gradient(135deg, #67e8f9, #22d3ee);
      color: #0f172a;
    }
    
    .stats-card {
      background: rgba(255, 255, 255, 0.1);
      backdrop-filter: blur(10px);
      border-radius: 15px;
      border: 1px solid rgba(255, 255, 255, 0.2);
      padding: 15px;
      margin-top: 20px;
    }
    
    .stat-item {
      display: flex;
      justify-content: space-between;
      padding: 10px 0;
      border-bottom: 1px solid rgba(255, 255, 255, 0.05);
    }
    
    .stat-item:last-child {
      border-bottom: none;
    }
    
    .stat-value {
      font-weight: 700;
      font-size: 18px;
      background: linear-gradient(to right, #fbcfe8, #c7d2fe);
      -webkit-background-clip: text;
      -webkit-text-fill-color: transparent;
    }
  `]
})
export class SidebarComponent {
  @Output() aiRecommend = new EventEmitter<void>();

  onAiRecommend() {
    this.aiRecommend.emit();
  }
}